<?php
/**
 * Finc Resolver Trait
 *
 * PHP version 5
 *
 * Copyright (C) Leipzig University Library 2015
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * @category VuFind
 * @package  Resolver_Drivers
 * @author   Robert Lange <lange@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development:plugins:link_resolver_drivers Wiki
 */
namespace finc\Resolver\Driver;

use \Zend\Config\Exception\InvalidArgumentException;

/**
 * Finc Link Resolver Driver
 *
 * @category VuFind
 * @package  Resolver_Drivers
 * @author   Robert Lange <lange@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development:plugins:link_resolver_drivers Wiki
 */
trait ResolverTrait
{
    /**
     * Get Resolver Url
     *
     * Transform the OpenURL as needed to get a working link to the resolver.
     *
     * @param string $openURL openURL (url-encoded)
     *
     * @return string Returns resolver specific url
     */
    public function getResolverUrl($openURL)
    {
        if (empty($this->baseUrl)) {
            throw new InvalidArgumentException(
                'Base url for link resolver is not correctly configured.'
            );
        }

        if (empty($openURL)) {
            return $this->baseUrl;
        }

        if ($openURL[0] === '?' || $openURL[0] === '&') {
            $openURL = substr($openURL, 1, strlen($openURL)-1);
        }

        if (strpos($this->baseUrl, '?') === false) {
            return $this->baseUrl . '?' . $openURL;
        } else {
            return $this->baseUrl . '&' . $openURL;
        }
    }
}
