<?php
/**
 * Permission Provider Factory Class
 *
 * PHP version 5
 *
 * Copyright (C) Villanova University 2014.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  Authorization
 * @author   Demian Katz <demian.katz@villanova.edu>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development:plugins:hierarchy_components Wiki
 */
namespace finc\Role\PermissionProvider;

use Zend\ServiceManager\ServiceManager;

/**
 * Permission Provider Factory Class
 *
 * @category VuFind
 * @package  Authorization
 * @author   Demian Katz <demian.katz@villanova.edu>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development:plugins:hierarchy_components Wiki
 *
 * @codeCoverageIgnore
 */
class Factory extends \VuFind\Role\PermissionProvider\Factory
{
    /**
     * Factory for Username
     *
     * @param ServiceManager $container Service manager.
     *
     * @return CatUserType
     */
    public static function getCatUserType(ServiceManager $container)
    {
        return new CatUserType(
            $container->get('ZfcRbac\Service\AuthorizationService'),
            $container->get('VuFind\ILSAuthenticator')
        );
    }

    /**
     * Factory for IpRangeFoFor
     *
     * @param ServiceManager $container Service manager.
     *
     * @return IpRangeFoFor
     */
    public static function getIpRangeFoFor(ServiceManager $container)
    {
        return new IpRangeFoFor(
            $container->get('Request'),
            $container->get('VuFind\IpAddressUtils')
        );
    }

    /**
     * Factory for IpRegExFoFor
     *
     * @param ServiceManager $container Service manager.
     *
     * @return IpRegExFoFor
     */
    public static function getIpRegExFoFor(ServiceManager $container)
    {
        return new IpRegExFoFor(
            $container->get('Request')
        );
    }
}
